@@ -1,4 +1,4 @@
-'''
+"""
 ********************************************************************************
 * Name: File IO
 * Author: Nathan Swain
@@ -6,7 +6,7 @@
 * Copyright: (c) Brigham Young University 2013
 * License: BSD 2-Clause
 ********************************************************************************
-'''
+"""
 
 # This file is purely for convenience
 from gsshapy.orm.cmt import MapTableFile
@@ -14,7 +14,7 @@ from gsshapy.orm.gag import PrecipFile
 from gsshapy.orm.cif import ChannelInputFile
 from gsshapy.orm.spn import StormPipeNetworkFile
 from gsshapy.orm.hmet import HmetFile
-from gsshapy.orm.snw import NwsrfsFile, OrthographicGageFile
+from gsshapy.orm.snw import NwsrfsFile, OrographicGageFile
 from gsshapy.orm.gpi import GridPipeFile
 from gsshapy.orm.gst import GridStreamFile
 from gsshapy.orm.tim import TimeSeriesFile
@@ -25,3 +25,4 @@ from gsshapy.orm.rep import ReplaceParamFile, ReplaceValFile
 from gsshapy.orm.lnd import LinkNodeDatasetFile
 from gsshapy.orm.idx import IndexMap
 from gsshapy.orm.generic import GenericFile
+from gsshapy.orm.wms_dataset import WMSDatasetFile
